import java.io.*;
import java.math.*;
import java.util.*;

public class TestsGen {
	static final int MX = 100_000;

    int testCount;

    void write(String s) throws IOException {
        PrintWriter pw = new PrintWriter(String.format("../tests/%02d", ++testCount));
        System.out.println(testCount);
        pw.println(s);
        pw.close();
    }
    
    Random random = new Random(43534543);

	void genSample() throws IOException {
		write("5 4\r\n1 2\r\n2 3\r\n3 4\r\n4 5");
		write("5 5\r\n1 2\r\n2 3\r\n1 3\r\n3 4\r\n4 5");
	}

	void write(int n, int m, int[] u, int[] v) throws IOException {
        PrintWriter pw = new PrintWriter(String.format("../tests/%02d", ++testCount));
        System.out.println(testCount);
		pw.println(n + " " + m);
		for (int i = 0; i < m; i++) {
			pw.println(u[i] + " " + v[i]);
		}
        pw.close();	 	
	}

	void genRandom(int n, int m) throws IOException {
		int U[] = new int[m], V[] = new int[m];
		HashSet<String> st = new HashSet<String>();
		for (int i = 0; i < m; i++) {
		 	while (true) {
		 	 	int u = random.nextInt(n) + 1;
				int v = random.nextInt(n) + 1;
				if (u > v) {
				 	int o = u;
					u = v;
					v = o;
				}
				String s = Integer.toString(u) + "#" + Integer.toString(v);
				if (u == v || st.contains(s)) {
				 	continue;
				}
				st.add(s);
				U[i] = u;
				V[i] = v;
				break;
			}
		}
		write(n, m, U, V);
	}

	void genMax() throws IOException {
	 	int n = MX, m = MX - 1;
		int u[] = new int[m], v[] = new int[m];
		for (int i = 0; i < m; i++) {
		 	u[i] = i + 1;
			v[i] = i + 2;
		}
		write(n, m, u, v);
	}

	void genForest(int n, int m) throws IOException {
		int u[] = new int[m], v[] = new int[m];
		int cur = 0;
		HashSet<String> st = new HashSet<String>();
		for (int i = 2; i <= n; i++) {
		 	if (random.nextInt(10) == 0) {
		 	 	continue;
			}
			int p = random.nextInt(i - 1) + 1;
			u[cur] = p;
			v[cur] = i;
			String s = Integer.toString(u[cur]) + "#" + Integer.toString(v[cur]);
			st.add(s);
			cur++;
		}
		while (cur < m) {
			u[cur] = random.nextInt(n) + 1;
			v[cur] = random.nextInt(n) + 1;
			String s = Integer.toString(u[cur]) + "#" + Integer.toString(v[cur]);
			if (u[cur] == v[cur] || st.contains(s)) {
			 	continue;
			}
			st.add(s);
			cur++;
		}
		write(n, m, u, v);
	}

    void run() throws IOException {
        new File("../tests").mkdir();
        
		genSample();    
		for (int i = 0; i < 10; i++) {
			int n = random.nextInt(100);
		 	genRandom(n + 1, random.nextInt(3 * n));
		}
		for (int i = 0; i < 15; i++) {
		 	int n = random.nextInt(80000) + 20001;
			int m = Math.min(MX, random.nextInt(10 * n));
			genRandom(n, m);
		}
		genMax();
		for (int i = 0; i < 10; i++) {
			int n = random.nextInt(80000) + 20000;
			int m = Math.min(MX, n + random.nextInt(n / 3));
		 	genForest(n, m);
		}
    }

    public static void main(String[] args) throws IOException {
        new TestsGen().run();    }

}
